grib2io.tables.section1 API documentation

# grib2io.tables.section1

View Source

      1table_1_0 = {
      2'0':'Experimental',
      3'1':'Version Implemented on 7 November 2001',
      4'2':'Version Implemented on 4 November 2003',
      5'3':'Version Implemented on 2 November 2005',
      6'4':'Version Implemented on 7 November 2007',
      7'5':'Version Implemented on 4 November 2009',
      8'6':'Version Implemented on 15 September 2010',
      9'7':'Version Implemented on 4 May 2011',
     10'8':'Version Implemented on 8 November 2011',
     11'9':'Version Implemented on 2 May 2012',
     12'10':'Version Implemented on 7 November 2012',
     13'11':'Version Implemented on 8 May 2013',
     14'12':'Version Implemented on 14 November 2013',
     15'13':'Version Implemented on 7 May 2014',
     16'14':'Version Implemented on 5 November 2014',
     17'16':'Version Implemented on 11 November 2015',
     18'17':'Version Implemented on 4 May 2016',
     19'18':'Version Implemented on 2 November 2016',
     20'19':'Version Implemented on 3 May 2017',
     21'20':'Version Implemented on 8 November 2017',
     22'21':'Version Implemented on 2 May 2018',
     23'22':'Version Implemented on 7 November 2018',
     24'23':'Version Implemented on 15 May 2019',
     25'24':'Version Implemented on 06 November 2019',
     26'25':'Pre-operational to be implemented by next amendment',
     27'25':'Version Implemented on 06 May 2020',
     28'26':'Pre-operational to be implemented by next amendment',
     29'27-254':'Future Version',
     30'255':'Missing"',
     31}
     32
     33table_1_1 = {
     34'0':'Local tables not used. Only table entries and templates from the current master table are valid.',
     35'1-254':'Number of local table version used.',
     36'255':'Missing',
     37}
     38
     39table_1_2 = {
     40'0':'Analysis',
     41'1':'Start of Forecast',
     42'2':'Verifying Time of Forecast',
     43'3':'Observation Time',
     44'4':'Local Time',
     45'5-191':'Reserved',
     46'192-254':'Reserved for Local Use',
     47'255':'Missing',
     48}
     49
     50table_1_3 = {
     51'0':'Operational Products',
     52'1':'Operational Test Products',
     53'2':'Research Products',
     54'3':'Re-Analysis Products',
     55'4':'THORPEX Interactive Grand Global Ensemble (TIGGE)',
     56'5':'THORPEX Interactive Grand Global Ensemble (TIGGE) test',
     57'6':'S2S Operational Products',
     58'7':'S2S Test Products',
     59'8':'Uncertainties in ensembles of regional reanalysis project (UERRA)',
     60'9':'Uncertainties in ensembles of regional reanalysis project (UERRA) Test',
     61'10':'Copernicus Regional Reanalysis',
     62'11':'Copernicus Regional Reanalysis Test',
     63'12-191':'Reserved',
     64'192-254':'Reserved for Local Use',
     65'255':'Missing',
     66}
     67
     68table_1_4 = {
     69'0':'Analysis Products',
     70'1':'Forecast Products',
     71'2':'Analysis and Forecast Products',
     72'3':'Control Forecast Products',
     73'4':'Perturbed Forecast Products',
     74'5':'Control and Perturbed Forecast Products',
     75'6':'Processed Satellite Observations',
     76'7':'Processed Radar Observations',
     77'8':'Event Probability',
     78'9-191':'Reserved',
     79'192-254':'Reserved for Local Use',
     80'192':'Experimental Products',
     81'255':'Missing',
     82}
     83
     84table_1_5 = {
     85'0':'Calendar Definition',
     86'1':'Paleontological Offset',
     87'2':'Calendar Definition and Paleontological Offset',
     88'3-32767':'Reserved',
     89'32768-65534':'Reserved for Local Use',
     90'65535':'Missing',
     91}
     92
     93table_1_6 = {
     94'0':'Gregorian',
     95'1':'360-day',
     96'2':'365-day',
     97'3':'Proleptic Gregorian',
     98'4-191':'Reserved',
     99'192-254':'Reserved for Local Use',
    100'255':'Missing',
    101}